@@ -18,10 +18,11 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     
 	$RCSfile: ConfigurationOptions.java,v $
-	$Date: 2008/04/17 15:02:01 $ 
+	$Date: 2009/05/04 17:58:42 $ 
 */
 package net.sf.statcvs.output;
 
+import java.awt.Color;
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
@@ -44,6 +45,11 @@ import net.sf.statcvs.weblinks.bugs.BugTracker;
 import net.sf.statcvs.weblinks.bugs.Bugzilla;
 import net.sf.statcvs.weblinks.bugs.Mantis;
 
+import org.jfree.chart.renderer.category.BarRenderer;
+import org.jfree.chart.renderer.category.StandardBarPainter;
+import org.jfree.chart.renderer.xy.StandardXYBarPainter;
+import org.jfree.chart.renderer.xy.XYBarRenderer;
+
 /**
  * Class for storing all command line parameters. The parameters
  * are set by the {@link net.sf.statcvs.Main#main} method. Interested classes
@@ -52,7 +58,7 @@ import net.sf.statcvs.weblinks.bugs.Mantis;
  * TODO: Should be moved to more appropriate package and made non-public
  * 
  * @author jentzsch
- * @version $Id: ConfigurationOptions.java,v 1.33 2008/04/17 15:02:01 benoitx Exp $
+ * @version $Id: ConfigurationOptions.java,v 1.38 2009/05/04 17:58:42 benoitx Exp $
  */
 public class ConfigurationOptions {
 
@@ -72,8 +78,10 @@ public class ConfigurationOptions {
     private static FilePatternMatcher excludePattern = null;
 
     private static Collection nonDeveloperLogins = new ArrayList();
-
-    private static CssHandler cssHandler = new DefaultCssHandler("statcvs.css");
+    private static boolean enableTwitterButton = true;
+    
+    private static CssHandler cssHandler = new DefaultCssHandler("objectlab-statcvs.css");
+    private static String charSet = "ISO-8859-1";
     private static WebRepositoryIntegration webRepository = null;
     private static Pattern symbolicNamesPattern;
 
@@ -81,6 +89,19 @@ public class ConfigurationOptions {
     private static String outputFormat = "html";
     private static Properties properties = new Properties();
 
+    static {
+        XYBarRenderer.setDefaultBarPainter(new StandardXYBarPainter());
+        BarRenderer.setDefaultBarPainter(new StandardBarPainter());
+    }
+
+    public static String getCharSet() {
+        return charSet;
+    }
+
+    public static void setCharSet(final String cs) {
+        charSet = cs;
+    }
+
     /**
      * returns the {@link CssHandler}
      * @return the CssHandler
@@ -485,4 +506,198 @@ public class ConfigurationOptions {
     public static Properties getConfigProperties() {
         return properties;
     }
+
+    /**
+     * Return a String prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static String getConfigStringProperty(final String propName, final String defaultValue) {
+        if (properties != null) {
+            return properties.getProperty(propName, defaultValue);
+        }
+        return defaultValue;
+    }
+
+    public static String getConfigStringProperty(final String propName, final String fallBackPropName, final String defaultValue) {
+        if (properties != null) {
+            final String val = properties.getProperty(propName);
+            if (val != null) {
+                return val;
+            } else {
+                return properties.getProperty(fallBackPropName, defaultValue);
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return a Integer prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static Integer getConfigIntegerProperty(final String propName, final Integer defaultValue) {
+        if (properties != null) {
+            final String val = properties.getProperty(propName);
+            if (val != null) {
+                try {
+                    return Integer.valueOf(val);
+                } catch (final NumberFormatException e) {
+                    return defaultValue;
+                }
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return a Float prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static Float getConfigIntegerProperty(final String propName, final Float defaultValue) {
+        if (properties != null) {
+            final String val = properties.getProperty(propName);
+            if (val != null) {
+                try {
+                    return Float.valueOf(val);
+                } catch (final NumberFormatException e) {
+                    return defaultValue;
+                }
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return a String prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static Color getConfigColorProperty(final String propName, final Color defaultValue) {
+        if (properties != null) {
+            String val = properties.getProperty(propName);
+            if (val != null) {
+                if (val.startsWith("#")) {
+                    val = val.substring(1);
+                }
+                val = val.toLowerCase();
+                if (val.length() > 6) {
+                    return defaultValue;
+                }
+                return new Color(Integer.parseInt(val, 16));
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return a Integer prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static Integer getConfigIntegerProperty(final String propName, final String fallBackPropName, final Integer defaultValue) {
+        if (properties != null) {
+            final String val = properties.getProperty(propName);
+            if (val != null) {
+                try {
+                    return Integer.valueOf(val);
+                } catch (final NumberFormatException e) {
+                    return defaultValue;
+                }
+            } else {
+                return getConfigIntegerProperty(fallBackPropName, defaultValue);
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return a Float prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static Float getConfigFloatProperty(final String propName, final String fallBackPropName, final Float defaultValue) {
+        if (properties != null) {
+            final String val = properties.getProperty(propName);
+            if (val != null) {
+                try {
+                    return Float.valueOf(val);
+                } catch (final NumberFormatException e) {
+                    return defaultValue;
+                }
+            } else {
+                return getConfigIntegerProperty(fallBackPropName, defaultValue);
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return a Boolean prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static Boolean getConfigBooleanProperty(final String propName, final String fallBackPropName, final Boolean defaultValue) {
+        if (properties != null) {
+            String val = properties.getProperty(propName);
+            if (val != null) {
+                try {
+                    return Boolean.valueOf(val);
+                } catch (final NumberFormatException e) {
+                    return defaultValue;
+                }
+            } else {
+                val = properties.getProperty(fallBackPropName);
+                if (val != null) {
+                    return Boolean.valueOf(val);
+                }
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return a Color prop.
+     * @param propName
+     * @param defaultValue
+     * @return
+     */
+    public static Color getConfigColorProperty(final String propName, final String fallBackPropName, final Color defaultValue) {
+        if (properties != null) {
+            String val = properties.getProperty(propName);
+            if (val != null) {
+                if (val.startsWith("#")) {
+                    val = val.substring(1);
+                }
+                val = val.toLowerCase();
+                if (val.length() > 6) {
+                    return defaultValue;
+                }
+                return new Color(Integer.parseInt(val, 16));
+            } else {
+                return getConfigColorProperty(fallBackPropName, defaultValue);
+            }
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Enable/disable the Twitter "Tweet This" Buttons.
+     * @param value
+     */
+    public static void setEnableTwitterButton(boolean value) {
+        enableTwitterButton = value;
+    }
+    
+    public static boolean isEnableTwitterButton() {
+        return enableTwitterButton;
+    }
 }
